@@ -1,6 +1,6 @@
 package DateTimeX::Mashup::Shiras::Types;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = qv("v0.36.4");
+use version; our $VERSION = qv("v0.36.6");
 use strict;
 use warnings;
 use 5.010;
@@ -148,15 +148,16 @@ declare_coercion DateTimeDateFromStr,
 			my	$bump_year = ( $century_postfix + 20 > 99 ) ? ( $century_postfix - 80 ) : undef;# The double digit years are probably less than 21 years in the future of the processing time
 			my	$drop_year = ( $century_postfix - 79 < 0 ) ? ( $century_postfix + 21 ) : undef;# The double digit years are probably less than 81 years in the past of the processing time
 			$str =~ /(\d{1,2})\D(\d{1,2})\D(\d{1,2})(\s|T)(\d{1,2})\D(\d{1,2})(\D(\d{1,2}))?/;
-			my $year = $3;
-			   $year = (
-					(defined $bump_year and $year <= $bump_year ) ? $century_prefix + 1 :
-					(defined $drop_year and $year >= $drop_year ) ? $century_prefix - 1 : $century_prefix ) . sprintf '%02u', $year;
-			my $us_str = sprintf "%u-%02u-%02uT%02u:%02u:%02u", $year, $1, $2, $5, $6, ($7//'00');
-			my $eu_str = sprintf "%u-%02u-%02uT%02u:%02u:%02u", $year, $2, $1, $5, $6, ($7//'00');
-			eval '$dt_us = DateTime::Format::Flexible->parse_datetime( $us_str )';
-			eval '$dt_eu = DateTime::Format::Flexible->parse_datetime( $eu_str )';# european => 1,
-			$str = $us_str;
+			if( defined $1 and defined $2 and defined $3 ){
+				my $year = $3;
+				   $year = (
+						(defined $bump_year and $year <= $bump_year ) ? $century_prefix + 1 :
+						(defined $drop_year and $year >= $drop_year ) ? $century_prefix - 1 : $century_prefix ) . sprintf '%02u', $year;
+				my $us_str = sprintf "%u-%02u-%02uT%02u:%02u:%02u", $year, $1, $2, $5, $6, ($7//'00');
+				my $eu_str = sprintf "%u-%02u-%02uT%02u:%02u:%02u", $year, $2, $1, $5, $6, ($7//'00');
+				eval '$dt_us = DateTime::Format::Flexible->parse_datetime( $us_str )';
+				eval '$dt_eu = DateTime::Format::Flexible->parse_datetime( $eu_str )';# european => 1,
+			}
 		}
 		my $return	= 
 			( $DateTimeX::Mashup::Shiras::Types::european_first and $dt_eu )? $dt_eu :
